/*===========================================================

   Template Name: iDocs - One Page Documentation HTML Template
   Author: Harnish Design
   Template URL: http://demo.harnishdesign.net/html/idocs
   Author URL: https://themeforest.net/user/harnishdesign
   File Description : Main css file of the template
	
=================================================
  Table of Contents
=================================================

	1. Basic
	2. Helpers Classes
	3. Layouts
		3.1 Side Navigation
		3.2 Docs Content
		3.3 Section Divider
	4. Header
		4.1 Main Navigation
	5 Elements
		5.1 List Style
		5.2 Changelog
		5.3 Accordion & Toggle
		5.4 Nav
		5.5 Tabs
		5.6 Popup Img
		5.7 Featured Box
	6 Footer
		6.1 Social Icons
		6.2 Back to Top
	7 Extra

=======================================================*/

//-------------------- Base Colors --------------------//

$primary-color: 			#0366d6;
$primary-color-hover: 		darken($primary-color, 7%);
$secondary-color: 			$secondary;

$body-bg:					#dddddd;
$text-color:				#4c4d4d;
$title-color:     			#252b33;